==> gtksourceview5_5.6.2.orig.tar.xz: gtksourceview-5.6.2/gtksourceview/gtksourcecompletion-private.h <==
/*
 * This file is part of GtkSourceView
 *
 * Copyright 2020 Christian Hergert <chergert@redhat.com>
 *
 * GtkSourceView is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * GtkSourceView is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, see <http://www.gnu.org/licenses/>.
 *
 * SPDX-License-Identifier: LGPL-2.1-or-later
 */

#pragma once

#include <gtk/gtk.h>

#include "gtksourcecompletion.h"
#include "gtksourcecompletionlist-private.h"

G_BEGIN_DECLS

GtkSourceCompletion     *_gtk_source_completion_new                (GtkSourceView               *view);
GtkSourceCompletionList *_gtk_source_completion_get_display        (GtkSourceCompletion         *self);
void                     _gtk_source_completion_set_font_desc      (GtkSourceCompletion         *self,
                                                                    const PangoFontDescription  *font_desc);
void                     _gtk_source_completion_activate           (GtkSourceCompletion         *self,
                                                                    GtkSourceCompletionContext  *context,
                                                                    GtkSourceCompletionProvider *provider,
                                                                    GtkSourceCompletionProposal *proposal);
gboolean                 _gtk_source_completion_get_select_on_show (GtkSourceCompletion         *self);
void                     _gtk_source_completion_css_changed        (GtkSourceCompletion         *self,
                                                                    GtkCssStyleChange           *change);

G_END_DECLS

==> gtksourceview-5.18.0.tar.xz: gtksourceview-5.18.0/gtksourceview/gtksourcecompletion-private.h <==
/*
 * This file is part of GtkSourceView
 *
 * Copyright 2020 Christian Hergert <chergert@redhat.com>
 *
 * GtkSourceView is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * GtkSourceView is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, see <http://www.gnu.org/licenses/>.
 *
 * SPDX-License-Identifier: LGPL-2.1-or-later
 */

#pragma once

#include <gtk/gtk.h>

#include "gtksourcecompletion.h"
#include "gtksourcecompletionlist-private.h"

G_BEGIN_DECLS

GtkSourceCompletion     *_gtk_source_completion_new                (GtkSourceView               *view);
GtkSourceCompletionList *_gtk_source_completion_get_display        (GtkSourceCompletion         *self);
void                     _gtk_source_completion_set_font_desc      (GtkSourceCompletion         *self,
                                                                    const PangoFontDescription  *font_desc);
void                     _gtk_source_completion_activate           (GtkSourceCompletion         *self,
                                                                    GtkSourceCompletionContext  *context,
                                                                    GtkSourceCompletionProvider *provider,
                                                                    GtkSourceCompletionProposal *proposal);
gboolean                 _gtk_source_completion_get_select_on_show (GtkSourceCompletion         *self);
void                     _gtk_source_completion_css_changed        (GtkSourceCompletion         *self,
                                                                    GtkCssStyleChange           *change);
gboolean                 _gtk_source_completion_get_visible        (GtkSourceCompletion         *self);
void                     _gtk_source_completion_move_cursor        (GtkSourceCompletion         *self,
                                                                    GtkMovementStep              step,
                                                                    int                          direction);

G_END_DECLS
